/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_qr1cpeep);
  numBytes += sLine_init(&sLine_YA5tE9ZW);
  numBytes += sLine_init(&sLine_Lxs1CT4r);
  numBytes += sLine_init(&sLine_M7ZkqRRp);
  numBytes += sLine_init(&sLine_oWl9UX9k);
  numBytes += sBiquad_init(&sBiquad_s_psbF7GrO);
  numBytes += sLine_init(&sLine_Y3VL6Up5);
  numBytes += sLine_init(&sLine_7F0Iy1n2);
  numBytes += sLine_init(&sLine_BkvbSdhi);
  numBytes += sLine_init(&sLine_iXXRw46K);
  numBytes += sBiquad_init(&sBiquad_s_J5Y0Kww7);
  numBytes += sLine_init(&sLine_viCUMOaV);
  numBytes += sLine_init(&sLine_jbmcAFq7);
  numBytes += sLine_init(&sLine_SrVD3fza);
  numBytes += sLine_init(&sLine_FL3g09MB);
  numBytes += sLine_init(&sLine_wL9REQJl);
  numBytes += sBiquad_init(&sBiquad_s_0sCPtc1l);
  numBytes += sLine_init(&sLine_8ysbQBpB);
  numBytes += sLine_init(&sLine_XevuE1MU);
  numBytes += sLine_init(&sLine_2OTBiuDF);
  numBytes += sLine_init(&sLine_ltqLCvNo);
  numBytes += sLine_init(&sLine_e2wYagdH);
  numBytes += sBiquad_init(&sBiquad_s_32QK89vp);
  numBytes += sLine_init(&sLine_sKxEBaVF);
  numBytes += sLine_init(&sLine_ZCc9FQ3S);
  numBytes += sLine_init(&sLine_D5uydbcL);
  numBytes += sLine_init(&sLine_VNJ3LWZc);
  numBytes += sBiquad_init(&sBiquad_s_5mCOEDxn);
  numBytes += sLine_init(&sLine_pDWysr7I);
  numBytes += sLine_init(&sLine_3tq71ZAO);
  numBytes += sLine_init(&sLine_96W9wN3x);
  numBytes += sLine_init(&sLine_VOZg2Mln);
  numBytes += sLine_init(&sLine_uE5CAFB6);
  numBytes += sBiquad_init(&sBiquad_s_9x4yNrfF);
  numBytes += sLine_init(&sLine_qNYd6fUl);
  numBytes += sPhasor_k_init(&sPhasor_aSSq0zQ2, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_mGgjHH19);
  numBytes += sRPole_init(&sRPole_Ide6KfcI);
  numBytes += sRPole_init(&sRPole_BHsJqVIn);
  numBytes += sTabhead_init(&sTabhead_BfSM2Maw, &hTable_YDMblDWI);
  numBytes += sTabread_init(&sTabread_17KefS5U, &hTable_YDMblDWI, false);
  numBytes += sTabread_init(&sTabread_GtAavHRB, &hTable_YDMblDWI, false);
  numBytes += sLine_init(&sLine_vpP7CNDs);
  numBytes += sTabhead_init(&sTabhead_ipTgnjpv, &hTable_eCZnRzuX);
  numBytes += sTabread_init(&sTabread_HTbfjjyE, &hTable_eCZnRzuX, false);
  numBytes += sTabread_init(&sTabread_VI3cMZLw, &hTable_eCZnRzuX, false);
  numBytes += sLine_init(&sLine_ddTGuu18);
  numBytes += sTabwrite_init(&sTabwrite_d6k9Y9DJ, &hTable_eCZnRzuX);
  numBytes += sTabwrite_init(&sTabwrite_8r0opVp0, &hTable_YDMblDWI);
  numBytes += sLine_init(&sLine_v6vYAkJS);
  numBytes += sPhasor_k_init(&sPhasor_0kAFjnUv, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_iy8sS39E);
  numBytes += sRPole_init(&sRPole_vub0EfSi);
  numBytes += sRPole_init(&sRPole_Qddm0OLI);
  numBytes += sTabhead_init(&sTabhead_Q582SIub, &hTable_gvXJTePX);
  numBytes += sTabread_init(&sTabread_0W6Fy8Zc, &hTable_gvXJTePX, false);
  numBytes += sTabread_init(&sTabread_XA9SFbl0, &hTable_gvXJTePX, false);
  numBytes += sLine_init(&sLine_zW8FhS2g);
  numBytes += sTabhead_init(&sTabhead_dvIRlkbo, &hTable_HqUfuLZA);
  numBytes += sTabread_init(&sTabread_O2H6Knxf, &hTable_HqUfuLZA, false);
  numBytes += sTabread_init(&sTabread_kViT4gSx, &hTable_HqUfuLZA, false);
  numBytes += sLine_init(&sLine_tfBHz0zv);
  numBytes += sTabwrite_init(&sTabwrite_IkxtV3Y1, &hTable_HqUfuLZA);
  numBytes += sTabwrite_init(&sTabwrite_GVTt7Ugm, &hTable_gvXJTePX);
  numBytes += sLine_init(&sLine_Pwz8mM05);
  numBytes += sPhasor_k_init(&sPhasor_1ymnvXLM, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_YN0C7G9z);
  numBytes += sRPole_init(&sRPole_qLgsIPYt);
  numBytes += sRPole_init(&sRPole_NXhUqfIZ);
  numBytes += sTabhead_init(&sTabhead_xC5gsYBU, &hTable_t2j1JVpz);
  numBytes += sTabread_init(&sTabread_3dfSv3hs, &hTable_t2j1JVpz, false);
  numBytes += sTabread_init(&sTabread_T9AswgjU, &hTable_t2j1JVpz, false);
  numBytes += sLine_init(&sLine_ind7E2o9);
  numBytes += sTabhead_init(&sTabhead_gv2POoB2, &hTable_H13OjF3D);
  numBytes += sTabread_init(&sTabread_wGF3Xmj3, &hTable_H13OjF3D, false);
  numBytes += sTabread_init(&sTabread_Pksf32qN, &hTable_H13OjF3D, false);
  numBytes += sLine_init(&sLine_LxyuLNfM);
  numBytes += sTabwrite_init(&sTabwrite_9h7bDaGc, &hTable_H13OjF3D);
  numBytes += sTabwrite_init(&sTabwrite_TKjU5b8i, &hTable_t2j1JVpz);
  numBytes += cVar_init_f(&cVar_6N2P0hLr, 0.0f);
  numBytes += cVar_init_f(&cVar_8Y3AvdzL, 0.0f);
  numBytes += cVar_init_f(&cVar_Y4pd2i06, 0.0f);
  numBytes += cVar_init_f(&cVar_8nq4YUSZ, 0.0f);
  numBytes += cSlice_init(&cSlice_NKlPq6AM, 1, -1);
  numBytes += cVar_init_f(&cVar_dD8ShTWG, 1337.0f);
  numBytes += cVar_init_f(&cVar_wS8RK0BN, 0.0f);
  numBytes += cIf_init(&cIf_knOEXho5, false);
  numBytes += cIf_init(&cIf_ezSVEw3E, false);
  numBytes += cBinop_init(&cBinop_TdAVNuVz, 0.0f); // __pow
  numBytes += cIf_init(&cIf_V6qGqG8w, false);
  numBytes += cBinop_init(&cBinop_babSBaZe, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XQsaJrfj, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_4Z1e53LB, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_EK9HdYd0, 0.0f);
  numBytes += cIf_init(&cIf_I9VnKYoL, false);
  numBytes += cIf_init(&cIf_NUV8094B, false);
  numBytes += cBinop_init(&cBinop_zITTjlmL, 0.0f); // __pow
  numBytes += cIf_init(&cIf_vx8VvW5Y, false);
  numBytes += cBinop_init(&cBinop_itRloXRg, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_G47qeSZc, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9Vqk0K5I, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_gbA7N0pL, 0.0f);
  numBytes += cIf_init(&cIf_tarN87SE, false);
  numBytes += cIf_init(&cIf_xuDEO1Go, false);
  numBytes += cBinop_init(&cBinop_Dtdr7Scv, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HV62il80, false);
  numBytes += cBinop_init(&cBinop_XsNQTVE4, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Ic58dgAZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VsuqByAl, -15.0f); // __eq
  numBytes += cIf_init(&cIf_SDW7DL3g, false);
  numBytes += cSlice_init(&cSlice_uKrq3yB8, 1, -1);
  numBytes += cVar_init_f(&cVar_cujZ2Fsm, 0.0f);
  numBytes += cSlice_init(&cSlice_O9IPkajm, 1, -1);
  numBytes += cVar_init_f(&cVar_mchbRH9f, 0.0f);
  numBytes += cSlice_init(&cSlice_T2cGsfA5, 1, -1);
  numBytes += cVar_init_f(&cVar_6z9PnJg0, 0.0f);
  numBytes += cSlice_init(&cSlice_ooX9K5cx, 1, -1);
  numBytes += cVar_init_f(&cVar_AGzI4t8e, 0.313f);
  numBytes += cBinop_init(&cBinop_Sqzyy7uE, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_CzAWYvwc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FkJvm8aa, 0.0f);
  numBytes += cVar_init_f(&cVar_kaP3wn3j, 1337.0f);
  numBytes += cVar_init_f(&cVar_ellpgQjh, 0.3f);
  numBytes += cBinop_init(&cBinop_yN0nYmFD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KMrTaJGY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uzSMaktB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3HSsEzb6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ygjrpm3f, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1VqUuOYa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FhnYxHME, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_4pwd8PTP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_x6bWVruG, 0.0f);
  numBytes += cVar_init_f(&cVar_slrckD6n, 1337.0f);
  numBytes += cVar_init_f(&cVar_sQofmCyt, 0.313f);
  numBytes += cBinop_init(&cBinop_Ut3pQmmZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qmzp5tMj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OWOabFjS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mjClmQYt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZVvj1TvL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V6WpG5w0, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_8a5gJpJx, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Dv2ge1I0, 0.0f);
  numBytes += cVar_init_f(&cVar_o69pDYTm, 1037.0f);
  numBytes += cVar_init_f(&cVar_0tpmBT9i, 0.4f);
  numBytes += cBinop_init(&cBinop_JN3vhhYS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qBcCqJIW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aoRFxVZy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dCzCNE5P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dP1MVnqZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BjuLBMCG, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ttCiEqun, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sBweHjZw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7BBkDdWK, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_ZHCWO8yj, 1, -1);
  numBytes += cVar_init_f(&cVar_6yaBKbAE, 1337.0f);
  numBytes += cVar_init_f(&cVar_xwcDa7Pz, 0.0f);
  numBytes += cIf_init(&cIf_1Z6jG9zX, false);
  numBytes += cIf_init(&cIf_7avjXTgT, false);
  numBytes += cBinop_init(&cBinop_E7h36DEK, 0.0f); // __pow
  numBytes += cIf_init(&cIf_80A9I5ZO, false);
  numBytes += cBinop_init(&cBinop_nmBGXGXp, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_mPW7e8A6, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yHGAII5U, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_cPykEOJk, 0.0f);
  numBytes += cIf_init(&cIf_QuVkV6mu, false);
  numBytes += cIf_init(&cIf_CISfgX8A, false);
  numBytes += cBinop_init(&cBinop_PP4fD71p, 0.0f); // __pow
  numBytes += cIf_init(&cIf_e94m3rjF, false);
  numBytes += cBinop_init(&cBinop_6ecfQCwt, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_JBJTpVSr, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_OtzOto9m, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_A9XBp6JI, 0.0f);
  numBytes += cIf_init(&cIf_Mh4zjpry, false);
  numBytes += cIf_init(&cIf_aZBCQnJz, false);
  numBytes += cBinop_init(&cBinop_oB4grSDn, 0.0f); // __pow
  numBytes += cIf_init(&cIf_mL8K7WoM, false);
  numBytes += cBinop_init(&cBinop_gpBBpYeb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_H6B2az17, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_uUJjTbLn, -15.0f); // __eq
  numBytes += cIf_init(&cIf_X4FbqnzU, false);
  numBytes += cSlice_init(&cSlice_lSV2W4J9, 1, -1);
  numBytes += cVar_init_f(&cVar_DIuxvv1Z, 0.0f);
  numBytes += cSlice_init(&cSlice_RyhnfWm2, 1, -1);
  numBytes += cVar_init_f(&cVar_vtlj73qs, 0.0f);
  numBytes += cSlice_init(&cSlice_p2mEKFdS, 1, -1);
  numBytes += cVar_init_f(&cVar_10WicyA6, 0.0f);
  numBytes += cSlice_init(&cSlice_Cjgmy9jM, 1, -1);
  numBytes += cVar_init_f(&cVar_gdHNRnqy, 0.313f);
  numBytes += cBinop_init(&cBinop_11PoUf3l, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Bo8o7rbf, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Jb6ZASUw, 0.0f);
  numBytes += cVar_init_f(&cVar_qCMbD48w, 1337.0f);
  numBytes += cVar_init_f(&cVar_4tGQFM36, 0.3f);
  numBytes += cBinop_init(&cBinop_lQ0LzQKg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k3SUUGtn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Atu4hkQT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MzOY5DWK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lH5f7eCJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Cc7a9lF1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oKwGi8TC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_zQ6Ej5kL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_BbtPfi49, 0.0f);
  numBytes += cVar_init_f(&cVar_C1xvQ1Tv, 1337.0f);
  numBytes += cVar_init_f(&cVar_CzT3dvE7, 0.313f);
  numBytes += cBinop_init(&cBinop_Aa8eae8o, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IhtTf5L6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_TDXYRynB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_i55mtCR3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tkEkgFok, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wf8114uX, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qA0t29c8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_5bvkCIg9, 0.0f);
  numBytes += cVar_init_f(&cVar_d8KPRMoa, 1037.0f);
  numBytes += cVar_init_f(&cVar_8y3E4xqD, 0.4f);
  numBytes += cBinop_init(&cBinop_D85PkUbt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cnrkoUbv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GMAMCpUn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MfsKdyNm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gU0bVTsG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_McxmcVcy, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_1WCoKflS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mtqkvQZ2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qk7YxDgO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_sTJnxQD9, 5705.6f);
  numBytes += cVar_init_f(&cVar_g1B3dmE9, 313.3f);
  numBytes += cBinop_init(&cBinop_Fd8rmKN0, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_jbhf16JM, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_u3y2Ns2t, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_zntS9TdA, 0.0f);
  numBytes += cVar_init_f(&cVar_5VTM89si, 0.0f);
  numBytes += cVar_init_f(&cVar_7mkBRV16, 0.0f);
  numBytes += cVar_init_f(&cVar_LnubFnCl, 0.0f);
  numBytes += cVar_init_f(&cVar_J7tIJIiL, 0.0f);
  numBytes += cVar_init_f(&cVar_40PWNdBi, 0.0f);
  numBytes += cVar_init_f(&cVar_DtvgWpAS, 0.0f);
  numBytes += cVar_init_f(&cVar_vtcmB4Fw, 0.0f);
  numBytes += cVar_init_f(&cVar_SEszYYO1, 0.0f);
  numBytes += cVar_init_f(&cVar_cr9U8nBu, 0.0f);
  numBytes += cVar_init_f(&cVar_QuOwtaxR, 0.0f);
  numBytes += cVar_init_f(&cVar_XhZPSVYT, 0.0f);
  numBytes += cVar_init_s(&cVar_Q2GblK2N, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_CSgJi2Pz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M7Jszxhc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_i2Lgxisq, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_Dh7T575h, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_qxpCoe9i, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gHvuEo4Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DX14AEFm, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_WDdUG2Fs, 0.0f);
  numBytes += cDelay_init(this, &cDelay_h2IvWvHb, 0.0f);
  numBytes += hTable_init(&hTable_eCZnRzuX, 256);
  numBytes += cDelay_init(this, &cDelay_ifIY0KGC, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hN37y9AI, 0.0f);
  numBytes += hTable_init(&hTable_YDMblDWI, 256);
  numBytes += cVar_init_f(&cVar_MLWLenhs, 14.0f);
  numBytes += cBinop_init(&cBinop_w76tORhF, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_atPASC2d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BAOSekNA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_2tqhOhIK, 14.0f);
  numBytes += cBinop_init(&cBinop_1GMrHyqX, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Rzj7KnDO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tUqKzdsW, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_2RPWtRw1, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_cY2zgRwV, 1, -1);
  numBytes += cVar_init_f(&cVar_xeTaMyqO, 0.2f);
  numBytes += cSlice_init(&cSlice_bLACW62F, 1, -1);
  numBytes += cVar_init_f(&cVar_DhuOtQbf, 0.0f);
  numBytes += cSlice_init(&cSlice_ZX6Qz4J9, 1, -1);
  numBytes += cVar_init_f(&cVar_l6l3mLfV, 2.0f);
  numBytes += cSlice_init(&cSlice_qJ8xujid, 1, -1);
  numBytes += cVar_init_f(&cVar_nJaElYrY, 0.5f);
  numBytes += cVar_init_s(&cVar_PRWW266o, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_NP1aZwzc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FDLwfvk8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5zNYxgBd, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_yLhL5Pix, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_lDTNSX0u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OiYS5oB3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vGJhvU7k, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_UY2krhXW, 0.0f);
  numBytes += cDelay_init(this, &cDelay_XCnwkRLN, 0.0f);
  numBytes += hTable_init(&hTable_HqUfuLZA, 256);
  numBytes += cDelay_init(this, &cDelay_JrskxZfa, 0.0f);
  numBytes += cDelay_init(this, &cDelay_XsrFi32F, 0.0f);
  numBytes += hTable_init(&hTable_gvXJTePX, 256);
  numBytes += cVar_init_f(&cVar_vAMGwd8g, 14.0f);
  numBytes += cBinop_init(&cBinop_mA9kvWCo, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HiPMxiXW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8Hjkxk4m, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_R91Kx3bq, 14.0f);
  numBytes += cBinop_init(&cBinop_4Y4yh7QL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_8rqWJ9qG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PpBkEqbU, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_VIFNhEgU, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_z9BpsKte, 1, -1);
  numBytes += cVar_init_f(&cVar_rtbxg7St, 0.2f);
  numBytes += cSlice_init(&cSlice_DQ8hCh7v, 1, -1);
  numBytes += cVar_init_f(&cVar_mEAFbbF8, 0.0f);
  numBytes += cSlice_init(&cSlice_OdstaG4I, 1, -1);
  numBytes += cVar_init_f(&cVar_rgLTGcKO, 2.0f);
  numBytes += cSlice_init(&cSlice_bAezqD6d, 1, -1);
  numBytes += cVar_init_f(&cVar_ilnIuaKA, 0.5f);
  numBytes += cVar_init_s(&cVar_SgfRqW1z, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_hpXofNmu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_M0iWlVkV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4mSDDmUB, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_zHUiAXDX, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_WFNc9U6L, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Uafbze2d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JLiweLU6, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Npufu9Cw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_PwFSRuzn, 0.0f);
  numBytes += hTable_init(&hTable_H13OjF3D, 256);
  numBytes += cDelay_init(this, &cDelay_bn2yNHWq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gxlx0yu0, 0.0f);
  numBytes += hTable_init(&hTable_t2j1JVpz, 256);
  numBytes += cVar_init_f(&cVar_pYFJInuq, 14.0f);
  numBytes += cBinop_init(&cBinop_lZNR8Tju, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tkFokDFz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fgUVcT0I, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6xl6qExe, 14.0f);
  numBytes += cBinop_init(&cBinop_7vwaLb41, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_krCyXWzx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_noOGaCuB, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_DziASqT1, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_GmuIdEHZ, 1, -1);
  numBytes += cVar_init_f(&cVar_a4lPbQ1X, 0.2f);
  numBytes += cSlice_init(&cSlice_jZ3lkEac, 1, -1);
  numBytes += cVar_init_f(&cVar_ssmeZUuv, 0.0f);
  numBytes += cSlice_init(&cSlice_8f4FaJdD, 1, -1);
  numBytes += cVar_init_f(&cVar_Byi1SYeB, 2.0f);
  numBytes += cSlice_init(&cSlice_zzhGBTSi, 1, -1);
  numBytes += cVar_init_f(&cVar_wOOjrMGU, 0.5f);
  numBytes += sVarf_init(&sVarf_cgDKvpYz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kr3C0WgK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vLTB31gB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y9oaYRgo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TYkHUUcn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zgp8ZjrR, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_eCZnRzuX);
  hTable_free(&hTable_YDMblDWI);
  hTable_free(&hTable_HqUfuLZA);
  hTable_free(&hTable_gvXJTePX);
  hTable_free(&hTable_H13OjF3D);
  hTable_free(&hTable_t2j1JVpz);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_eCZnRzuX; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_YDMblDWI; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_HqUfuLZA; // del-1397-flanger-r
    case 0x578173CB: return &hTable_gvXJTePX; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_H13OjF3D; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_t2j1JVpz; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BrY6BfPR_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5341HLKg_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_om2gSoJR_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R1xJEcVa_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GGbXnmoz_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8QSRKvRO_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xRpDdHFF_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YVxQmolm_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VMtdJ5TH_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e6cgufp9_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VrE75FPA_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K5iPhQhx_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Yvjg5olu_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0KqcKFnA_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RWjcCfs8_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NmDWRt4A_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X7Jbvc33_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZIOlDtAH_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LcvbkXFb_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jj1ATMLo_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J20NwS4U_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Rg6kBSpu_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FFLORQk6_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_myC3Ju7I_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tPPoLJfi_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LIPyz3hJ_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YH0mNZUZ_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oqJtjiJF_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JyD1A8yD_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vnz4Dq3Y_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_on6tXHEE_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mhmmJfI7_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gJoVKR0S_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BnadlV5c_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vHjIyZyd_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Vmu84IVi_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A3QnRbdC_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lSKngjFK_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3PqO7Fv5_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yckM5lrB_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QWraSSkP_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EFitRDIS_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7oUt5WTp_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0MyopZAM_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9dJt3I2g_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LQW7bOHb_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0y3TJLH7_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jimYmw0Y_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5v8DEiqM_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rvvAgXyT_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ein91BTh_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IGS9p1MP_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z1n31wp8_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bXiej0F4_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IgpVDOVj_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n1eH0XpC_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_73LPMVlV_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_6N2P0hLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SbiPFcwI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_8Y3AvdzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xsGG3lDQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Y4pd2i06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sSr5vV1o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_8nq4YUSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8MVa5Gc0_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LJGrCP9I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sJkxWj9P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z6ohelNQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_HBfQqEEw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NKlPq6AM, 0, m, &cSlice_NKlPq6AM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g52QrEoz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_NKlPq6AM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dfRZrM9w_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dfRZrM9w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_dD8ShTWG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dfRZrM9w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_dfRZrM9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LcvbkXFb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_wS8RK0BN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1RP3dGsO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_knOEXho5, 0, m, &cIf_knOEXho5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_knOEXho5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XPYfa9Sq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_ezSVEw3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YSj7hG9v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_R09WpGUO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_w7wjbpPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TdAVNuVz, HV_BINOP_POW, 0, m, &cBinop_TdAVNuVz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TdAVNuVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V6qGqG8w, 0, m, &cIf_V6qGqG8w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x0Cc0Xum_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_cStFrIid_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_xxeTMYB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ezSVEw3E, 0, m, &cIf_ezSVEw3E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ozdk7jly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1pLCva8U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1pLCva8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ezSVEw3E, 1, m, &cIf_ezSVEw3E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_R09WpGUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_x0Cc0Xum_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_YSj7hG9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_V6qGqG8w, 0, m, &cIf_V6qGqG8w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cStFrIid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TdAVNuVz, HV_BINOP_POW, 1, m, &cBinop_TdAVNuVz_sendMessage);
  cMsg_w7wjbpPq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_V6qGqG8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_ttCiEqun, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_1RP3dGsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_knOEXho5, 1, m, &cIf_knOEXho5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XPYfa9Sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQsaJrfj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XQsaJrfj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Z1e53LB, HV_BINOP_EQ, 1, m, &cBinop_4Z1e53LB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZjeMMk9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_babSBaZe, HV_BINOP_ADD, 0, m, &cBinop_babSBaZe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_babSBaZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ozdk7jly_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xxeTMYB7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XQsaJrfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V6qGqG8w, 1, m, &cIf_V6qGqG8w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4Z1e53LB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qpYY5JHH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_qpYY5JHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ttCiEqun, m);
}

void Heavy_WSTD_FL3NGR::cCast_1ph9Etbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZjeMMk9M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_IMh9jPJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wS8RK0BN, 0, m, &cVar_wS8RK0BN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_30xoAv7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_babSBaZe, HV_BINOP_ADD, 1, m, &cBinop_babSBaZe_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XQsaJrfj, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XQsaJrfj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Z1e53LB, HV_BINOP_EQ, 0, m, &cBinop_4Z1e53LB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_EK9HdYd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xEdU68lf_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_I9VnKYoL, 0, m, &cIf_I9VnKYoL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_I9VnKYoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UQQjJi9F_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_NUV8094B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WeIlz7jL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_pKBJNbCF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_jgSQmRXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zITTjlmL, HV_BINOP_POW, 0, m, &cBinop_zITTjlmL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zITTjlmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vx8VvW5Y, 0, m, &cIf_vx8VvW5Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GI2WweyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_FRfyLoqO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1cPGte6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NUV8094B, 0, m, &cIf_NUV8094B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Qwq2fmCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9a5COVCv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9a5COVCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NUV8094B, 1, m, &cIf_NUV8094B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pKBJNbCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_GI2WweyX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WeIlz7jL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vx8VvW5Y, 0, m, &cIf_vx8VvW5Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FRfyLoqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zITTjlmL, HV_BINOP_POW, 1, m, &cBinop_zITTjlmL_sendMessage);
  cMsg_jgSQmRXj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_vx8VvW5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_am0SxpOU_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eUh0KP1P_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_tsqY4C1C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_xEdU68lf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I9VnKYoL, 1, m, &cIf_I9VnKYoL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UQQjJi9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G47qeSZc, HV_BINOP_GREATER_THAN, 1, m, &cBinop_G47qeSZc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Vqk0K5I, HV_BINOP_EQ, 1, m, &cBinop_9Vqk0K5I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BuCUqCN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_itRloXRg, HV_BINOP_ADD, 0, m, &cBinop_itRloXRg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_itRloXRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qwq2fmCQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1cPGte6N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G47qeSZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vx8VvW5Y, 1, m, &cIf_vx8VvW5Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9Vqk0K5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4XEaT4tN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4XEaT4tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_am0SxpOU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eUh0KP1P_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_tsqY4C1C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pay3m2jb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_itRloXRg, HV_BINOP_ADD, 1, m, &cBinop_itRloXRg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_G47qeSZc, HV_BINOP_GREATER_THAN, 0, m, &cBinop_G47qeSZc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Vqk0K5I, HV_BINOP_EQ, 0, m, &cBinop_9Vqk0K5I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lWPWXuNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EK9HdYd0, 0, m, &cVar_EK9HdYd0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UvVXSFCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BuCUqCN3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_gbA7N0pL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_izAkDCK8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_tarN87SE, 0, m, &cIf_tarN87SE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_tarN87SE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_89KgchBU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_xuDEO1Go_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WgUbilen_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VBJRDdZe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_u2UBikWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dtdr7Scv, HV_BINOP_POW, 0, m, &cBinop_Dtdr7Scv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dtdr7Scv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HV62il80, 0, m, &cIf_HV62il80_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PfdlHSpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_J9WLx2KA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BopWy3fS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xuDEO1Go, 0, m, &cIf_xuDEO1Go_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UpWPyNn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RxGAI5pn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RxGAI5pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xuDEO1Go, 1, m, &cIf_xuDEO1Go_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VBJRDdZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_PfdlHSpo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WgUbilen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HV62il80, 0, m, &cIf_HV62il80_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J9WLx2KA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dtdr7Scv, HV_BINOP_POW, 1, m, &cBinop_Dtdr7Scv_sendMessage);
  cMsg_u2UBikWh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_HV62il80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_7BBkDdWK, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_izAkDCK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tarN87SE, 1, m, &cIf_tarN87SE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_89KgchBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ic58dgAZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Ic58dgAZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VsuqByAl, HV_BINOP_EQ, 1, m, &cBinop_VsuqByAl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5OydxrBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XsNQTVE4, HV_BINOP_ADD, 0, m, &cBinop_XsNQTVE4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XsNQTVE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UpWPyNn5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BopWy3fS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ic58dgAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HV62il80, 1, m, &cIf_HV62il80_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VsuqByAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WlBy8ebR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WlBy8ebR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7BBkDdWK, m);
}

void Heavy_WSTD_FL3NGR::cCast_uZO6aXwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XsNQTVE4, HV_BINOP_ADD, 1, m, &cBinop_XsNQTVE4_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ic58dgAZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Ic58dgAZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VsuqByAl, HV_BINOP_EQ, 0, m, &cBinop_VsuqByAl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yfw2DB0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gbA7N0pL, 0, m, &cVar_gbA7N0pL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dZNuKybk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5OydxrBL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_SDW7DL3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_sBweHjZw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_RTFPvQsk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uKrq3yB8, 0, m, &cSlice_uKrq3yB8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_a6grC2Wo_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_uKrq3yB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SIYDpEiU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SIYDpEiU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_cujZ2Fsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SIYDpEiU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SIYDpEiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_X7Jbvc33_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_a6grC2Wo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_O9IPkajm, 0, m, &cSlice_O9IPkajm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HBfQqEEw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_O9IPkajm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jccU2der_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jccU2der_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_mchbRH9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jccU2der_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_jccU2der_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_J20NwS4U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_g52QrEoz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_T2cGsfA5, 0, m, &cSlice_T2cGsfA5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zAEBSCbN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_T2cGsfA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_v258vsI6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_v258vsI6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6z9PnJg0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v258vsI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_v258vsI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZIOlDtAH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zAEBSCbN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ooX9K5cx, 0, m, &cSlice_ooX9K5cx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ooX9K5cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M1EWW9K7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M1EWW9K7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_AGzI4t8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M1EWW9K7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_M1EWW9K7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jj1ATMLo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_Es2suv0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qr1cpeep, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WqJ8L6ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YA5tE9ZW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_E7xSifvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lxs1CT4r, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ei1s71Ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M7ZkqRRp, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_M7QA7Wsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oWl9UX9k, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8IKnPMD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eCgYywcj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_eCgYywcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sqzyy7uE, HV_BINOP_DIVIDE, 1, m, &cBinop_Sqzyy7uE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3zycf78m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_RwSloTbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wCYT5e8A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4Rlyddmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_RwSloTbj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wCYT5e8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sqzyy7uE, HV_BINOP_DIVIDE, 0, m, &cBinop_Sqzyy7uE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3zycf78m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Rlyddmb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Sqzyy7uE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CzAWYvwc, HV_BINOP_MULTIPLY, 1, m, &cBinop_CzAWYvwc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CzAWYvwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sKcAxSpW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NOFjkuOD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Wari6NyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HSmMhte2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_E8fdh8BJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hw2qseQj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cHYnUDrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_hctjaA9J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hctjaA9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CzAWYvwc, HV_BINOP_MULTIPLY, 0, m, &cBinop_CzAWYvwc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_42sv749Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_OgIfU1yZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OgIfU1yZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_31rR7Qlk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_8JeOWeUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FkJvm8aa, 1, m, &cVar_FkJvm8aa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_FkJvm8aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xjikTIDo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6MaAIgCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KMrTaJGY, HV_BINOP_MULTIPLY, 1, m, &cBinop_KMrTaJGY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VpfCsnpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6MaAIgCL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W291dg76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_uTQEnTKX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uTQEnTKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uzSMaktB, HV_BINOP_MULTIPLY, 1, m, &cBinop_uzSMaktB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bRC3E1od_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3HSsEzb6, HV_BINOP_MULTIPLY, 1, m, &cBinop_3HSsEzb6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oi92zc6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bRC3E1od_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7hFMJcKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygjrpm3f, HV_BINOP_MULTIPLY, 1, m, &cBinop_ygjrpm3f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ATC2vpR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aVVhaAlX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aVVhaAlX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1VqUuOYa, HV_BINOP_MULTIPLY, 1, m, &cBinop_1VqUuOYa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_kaP3wn3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Njo4wi01_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_cHYnUDrO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hPHmNBKK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ellpgQjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_42sv749Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NOFjkuOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_E8fdh8BJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sKcAxSpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Wari6NyI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_HSmMhte2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_myC3Ju7I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hw2qseQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FFLORQk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_2wCfMado_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Rg6kBSpu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_31rR7Qlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gYCASrNO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gYCASrNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yN0nYmFD, HV_BINOP_MULTIPLY, 1, m, &cBinop_yN0nYmFD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yN0nYmFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pmmdTMJC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pmmdTMJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2wCfMado_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_xjikTIDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZbjJ8BT3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZbjJ8BT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qX2oKcZT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6OUBtXzR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gUhqXge7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KJjpl4YP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tfWs8pbs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0CShZPuK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KMrTaJGY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Es2suv0h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uzSMaktB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WqJ8L6ke_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3HSsEzb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E7xSifvs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ygjrpm3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ei1s71Ue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1VqUuOYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M7QA7Wsx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_gbLI6bqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kaP3wn3j, 0, m, &cVar_kaP3wn3j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ygru7NfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ellpgQjh, 1, m, &cVar_ellpgQjh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gUhqXge7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ygjrpm3f, HV_BINOP_MULTIPLY, 0, m, &cBinop_ygjrpm3f_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_KJjpl4YP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3HSsEzb6, HV_BINOP_MULTIPLY, 0, m, &cBinop_3HSsEzb6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_6OUBtXzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1VqUuOYa, HV_BINOP_MULTIPLY, 0, m, &cBinop_1VqUuOYa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0CShZPuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KMrTaJGY, HV_BINOP_MULTIPLY, 0, m, &cBinop_KMrTaJGY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_tfWs8pbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uzSMaktB, HV_BINOP_MULTIPLY, 0, m, &cBinop_uzSMaktB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qX2oKcZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_Njo4wi01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ellpgQjh, 0, m, &cVar_ellpgQjh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hPHmNBKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FkJvm8aa, 0, m, &cVar_FkJvm8aa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FIbRepUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y3VL6Up5, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SDF5zJ9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7F0Iy1n2, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_DBSYzaGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BkvbSdhi, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_dz6aqbia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iXXRw46K, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_65zoR3nA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C1ny7KId_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_C1ny7KId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FhnYxHME, HV_BINOP_DIVIDE, 1, m, &cBinop_FhnYxHME_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_npJUznE5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_uO8bROxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_EWLhAN4n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8YogCQ8U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_uO8bROxj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EWLhAN4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FhnYxHME, HV_BINOP_DIVIDE, 0, m, &cBinop_FhnYxHME_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_npJUznE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8YogCQ8U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_FhnYxHME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pwd8PTP, HV_BINOP_MULTIPLY, 1, m, &cBinop_4pwd8PTP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4pwd8PTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bONJV8tr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CgQF5vor_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_ndamYP91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gwaTONso_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_H3ky5zkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vkNaGsZD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yHB6K7D6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_IQmp5g7u_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IQmp5g7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pwd8PTP, HV_BINOP_MULTIPLY, 0, m, &cBinop_4pwd8PTP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VbQYMfL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9jPNFzpw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9jPNFzpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j65EMGIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xn4mE1CR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OWOabFjS, HV_BINOP_MULTIPLY, 1, m, &cBinop_OWOabFjS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_o4WfNTcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x6bWVruG, 1, m, &cVar_x6bWVruG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eU4C9YuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mjClmQYt, HV_BINOP_MULTIPLY, 1, m, &cBinop_mjClmQYt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_iYadGocx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aFeT3cqI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aFeT3cqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZVvj1TvL, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZVvj1TvL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_x6bWVruG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fChKBsEY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_slrckD6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GkXFuzio_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_yHB6K7D6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mb7VZCXu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sQofmCyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_VbQYMfL6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CgQF5vor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_H3ky5zkK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bONJV8tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ndamYP91_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_gwaTONso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YH0mNZUZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vkNaGsZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LIPyz3hJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_hCne2vkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tPPoLJfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_j65EMGIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_N6g5v6va_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N6g5v6va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ut3pQmmZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ut3pQmmZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ut3pQmmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_r2eBlI9s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_r2eBlI9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hCne2vkM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fChKBsEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_PypMx54E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PypMx54E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EcIbgD83_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g7TF0Hg4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AAMVU7DL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gOiYfpCC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qmzp5tMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FIbRepUm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OWOabFjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SDF5zJ9c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mjClmQYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DBSYzaGl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ZVvj1TvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dz6aqbia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_TW6RZFS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_slrckD6n, 0, m, &cVar_slrckD6n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dGxmiy6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sQofmCyt, 1, m, &cVar_sQofmCyt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Mb7VZCXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x6bWVruG, 0, m, &cVar_x6bWVruG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GkXFuzio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sQofmCyt, 0, m, &cVar_sQofmCyt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AAMVU7DL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OWOabFjS, HV_BINOP_MULTIPLY, 0, m, &cBinop_OWOabFjS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_g7TF0Hg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mjClmQYt, HV_BINOP_MULTIPLY, 0, m, &cBinop_mjClmQYt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EcIbgD83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZVvj1TvL, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZVvj1TvL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gOiYfpCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qmzp5tMj, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qmzp5tMj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_5UJljLcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_viCUMOaV, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_XkX40eEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jbmcAFq7, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ZKLYghld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SrVD3fza, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cBp16nv8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FL3g09MB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_72QSyiwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wL9REQJl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_brafyuXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MN2KVVoe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_MN2KVVoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V6WpG5w0, HV_BINOP_DIVIDE, 1, m, &cBinop_V6WpG5w0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XJ4hKg1S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_plcNQEzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_xbjhyHGT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_i0M7NPUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_plcNQEzF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xbjhyHGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V6WpG5w0, HV_BINOP_DIVIDE, 0, m, &cBinop_V6WpG5w0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XJ4hKg1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i0M7NPUI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_V6WpG5w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8a5gJpJx, HV_BINOP_MULTIPLY, 1, m, &cBinop_8a5gJpJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8a5gJpJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zmvcjf17_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5LSDxQXI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_IlSEGuiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_boV0C7lx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_gSH9D4LD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eSt4Och6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DEJI1xa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eqDVUrT8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eqDVUrT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8a5gJpJx, HV_BINOP_MULTIPLY, 0, m, &cBinop_8a5gJpJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kgoG9bl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_TdpBZZ79_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TdpBZZ79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C5ZaFNzA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_L5kydWii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qBcCqJIW, HV_BINOP_MULTIPLY, 1, m, &cBinop_qBcCqJIW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_o5hkMWhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OWcYAn3g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OWcYAn3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_L5kydWii_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9URWf9qR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_RmH4nTSb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RmH4nTSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aoRFxVZy, HV_BINOP_MULTIPLY, 1, m, &cBinop_aoRFxVZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eQbP6y4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dCzCNE5P, HV_BINOP_MULTIPLY, 1, m, &cBinop_dCzCNE5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tKo32qYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QLDGIpWj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QLDGIpWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eQbP6y4x_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oN5FRzA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dv2ge1I0, 1, m, &cVar_Dv2ge1I0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HVUXew5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dP1MVnqZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_dP1MVnqZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HSS4oLL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ikBTwAIX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ikBTwAIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BjuLBMCG, HV_BINOP_MULTIPLY, 1, m, &cBinop_BjuLBMCG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Dv2ge1I0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8PRIFcLs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_o69pDYTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s8J0hhhh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_DEJI1xa3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j7E9WgKg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_0tpmBT9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kgoG9bl2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5LSDxQXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_gSH9D4LD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zmvcjf17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_IlSEGuiI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_boV0C7lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vnz4Dq3Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_eSt4Och6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JyD1A8yD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_QGPc88Cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oqJtjiJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_C5ZaFNzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RQgoqxDK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RQgoqxDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JN3vhhYS, HV_BINOP_MULTIPLY, 1, m, &cBinop_JN3vhhYS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JN3vhhYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lK2B2AeB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lK2B2AeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QGPc88Cu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_8PRIFcLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TZt8Zx7t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TZt8Zx7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0PzwvERI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hlg53XqQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wqofB6C4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jRI8MyCu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iLL4RDvK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9fsR7wP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qBcCqJIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5UJljLcM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aoRFxVZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XkX40eEV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dCzCNE5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKLYghld_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dP1MVnqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cBp16nv8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BjuLBMCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_72QSyiwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_HtJ0tkWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o69pDYTm, 0, m, &cVar_o69pDYTm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T1yEldGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0tpmBT9i, 1, m, &cVar_0tpmBT9i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_iLL4RDvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aoRFxVZy, HV_BINOP_MULTIPLY, 0, m, &cBinop_aoRFxVZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0PzwvERI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_wqofB6C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dP1MVnqZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_dP1MVnqZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_jRI8MyCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dCzCNE5P, HV_BINOP_MULTIPLY, 0, m, &cBinop_dCzCNE5P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Hlg53XqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BjuLBMCG, HV_BINOP_MULTIPLY, 0, m, &cBinop_BjuLBMCG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_V9fsR7wP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qBcCqJIW, HV_BINOP_MULTIPLY, 0, m, &cBinop_qBcCqJIW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_j7E9WgKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dv2ge1I0, 0, m, &cVar_Dv2ge1I0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_s8J0hhhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0tpmBT9i, 0, m, &cVar_0tpmBT9i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_am0SxpOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SDW7DL3g, 1, m, &cIf_SDW7DL3g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_1KeOQAF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_sBweHjZw, m);
}

void Heavy_WSTD_FL3NGR::cBinop_eUh0KP1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1KeOQAF8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_tsqY4C1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SDW7DL3g, 0, m, &cIf_SDW7DL3g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_BvPR4Pv3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZHCWO8yj, 0, m, &cSlice_ZHCWO8yj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_A9mnWIvQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ZHCWO8yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MfJyCJam_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MfJyCJam_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6yaBKbAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MfJyCJam_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MfJyCJam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gJoVKR0S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_xwcDa7Pz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IvelYVyt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_1Z6jG9zX, 0, m, &cIf_1Z6jG9zX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_1Z6jG9zX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GMrURHvk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_7avjXTgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_H12A4Otv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qr66P8JM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_7OQ8YiKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_E7h36DEK, HV_BINOP_POW, 0, m, &cBinop_E7h36DEK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E7h36DEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_80A9I5ZO, 0, m, &cIf_80A9I5ZO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kpoNMj7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_wNMLUFZh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MBs9pYTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_3crHgLEP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_48CwWHMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7avjXTgT, 0, m, &cIf_7avjXTgT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3crHgLEP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7avjXTgT, 1, m, &cIf_7avjXTgT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qr66P8JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_kpoNMj7i_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_H12A4Otv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_80A9I5ZO, 0, m, &cIf_80A9I5ZO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_wNMLUFZh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E7h36DEK, HV_BINOP_POW, 1, m, &cBinop_E7h36DEK_sendMessage);
  cMsg_7OQ8YiKG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_80A9I5ZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_1WCoKflS, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_IvelYVyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1Z6jG9zX, 1, m, &cIf_1Z6jG9zX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GMrURHvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mPW7e8A6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_mPW7e8A6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHGAII5U, HV_BINOP_EQ, 1, m, &cBinop_yHGAII5U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nX8Dar4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nmBGXGXp, HV_BINOP_ADD, 0, m, &cBinop_nmBGXGXp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nmBGXGXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MBs9pYTx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_48CwWHMd_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mPW7e8A6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_80A9I5ZO, 1, m, &cIf_80A9I5ZO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yHGAII5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7P5hy9t2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_7P5hy9t2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1WCoKflS, m);
}

void Heavy_WSTD_FL3NGR::cCast_1E0PqIMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nX8Dar4E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_pn7CpLUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nmBGXGXp, HV_BINOP_ADD, 1, m, &cBinop_nmBGXGXp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mPW7e8A6, HV_BINOP_GREATER_THAN, 0, m, &cBinop_mPW7e8A6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yHGAII5U, HV_BINOP_EQ, 0, m, &cBinop_yHGAII5U_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_obOCQaGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xwcDa7Pz, 0, m, &cVar_xwcDa7Pz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_cPykEOJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JWJQWKYj_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QuVkV6mu, 0, m, &cIf_QuVkV6mu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_QuVkV6mu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4u9zhH33_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_CISfgX8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_NoQMUJ44_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3OhPorbY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_8VtQsTfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PP4fD71p, HV_BINOP_POW, 0, m, &cBinop_PP4fD71p_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PP4fD71p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e94m3rjF, 0, m, &cIf_e94m3rjF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bb7NyFyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3ARdoNyf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5XQWPhyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CISfgX8A, 0, m, &cIf_CISfgX8A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AIJPPGWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YfgIsdiW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YfgIsdiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CISfgX8A, 1, m, &cIf_CISfgX8A_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3OhPorbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_bb7NyFyJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NoQMUJ44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_e94m3rjF, 0, m, &cIf_e94m3rjF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3ARdoNyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PP4fD71p, HV_BINOP_POW, 1, m, &cBinop_PP4fD71p_sendMessage);
  cMsg_8VtQsTfx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_e94m3rjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QdjkNIKx_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TGWP7lb2_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_QZ7V2qDN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_JWJQWKYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QuVkV6mu, 1, m, &cIf_QuVkV6mu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4u9zhH33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBJTpVSr, HV_BINOP_GREATER_THAN, 1, m, &cBinop_JBJTpVSr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OtzOto9m, HV_BINOP_EQ, 1, m, &cBinop_OtzOto9m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nsp6QN7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ecfQCwt, HV_BINOP_ADD, 0, m, &cBinop_6ecfQCwt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6ecfQCwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AIJPPGWm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5XQWPhyi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_JBJTpVSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e94m3rjF, 1, m, &cIf_e94m3rjF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OtzOto9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e5L25clE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_e5L25clE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QdjkNIKx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TGWP7lb2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_QZ7V2qDN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sIbRVwUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cPykEOJk, 0, m, &cVar_cPykEOJk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lrjBQU7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ecfQCwt, HV_BINOP_ADD, 1, m, &cBinop_6ecfQCwt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBJTpVSr, HV_BINOP_GREATER_THAN, 0, m, &cBinop_JBJTpVSr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OtzOto9m, HV_BINOP_EQ, 0, m, &cBinop_OtzOto9m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_H8QkxApH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nsp6QN7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_A9XBp6JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fZjozHu4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Mh4zjpry, 0, m, &cIf_Mh4zjpry_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_Mh4zjpry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pUnfQrkN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_aZBCQnJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_k7LOpqIu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OzJPre5f_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_HtDhnpey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oB4grSDn, HV_BINOP_POW, 0, m, &cBinop_oB4grSDn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oB4grSDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mL8K7WoM, 0, m, &cIf_mL8K7WoM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_O1K87Go8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_S19qkWhl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_srwyDogn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aZBCQnJz, 0, m, &cIf_aZBCQnJz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_B8uZk4Wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5r4qt63J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5r4qt63J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aZBCQnJz, 1, m, &cIf_aZBCQnJz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OzJPre5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_O1K87Go8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_k7LOpqIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mL8K7WoM, 0, m, &cIf_mL8K7WoM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_S19qkWhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oB4grSDn, HV_BINOP_POW, 1, m, &cBinop_oB4grSDn_sendMessage);
  cMsg_HtDhnpey_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_mL8K7WoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qk7YxDgO, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_fZjozHu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Mh4zjpry, 1, m, &cIf_Mh4zjpry_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pUnfQrkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H6B2az17, HV_BINOP_GREATER_THAN, 1, m, &cBinop_H6B2az17_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uUJjTbLn, HV_BINOP_EQ, 1, m, &cBinop_uUJjTbLn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2ZD6zHWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpBBpYeb, HV_BINOP_ADD, 0, m, &cBinop_gpBBpYeb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gpBBpYeb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B8uZk4Wy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_srwyDogn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_H6B2az17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mL8K7WoM, 1, m, &cIf_mL8K7WoM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uUJjTbLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pSvtmM0y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_pSvtmM0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qk7YxDgO, m);
}

void Heavy_WSTD_FL3NGR::cCast_RsjCeQK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A9XBp6JI, 0, m, &cVar_A9XBp6JI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OJm1OYrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ZD6zHWM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_62RhIq7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gpBBpYeb, HV_BINOP_ADD, 1, m, &cBinop_gpBBpYeb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H6B2az17, HV_BINOP_GREATER_THAN, 0, m, &cBinop_H6B2az17_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uUJjTbLn, HV_BINOP_EQ, 0, m, &cBinop_uUJjTbLn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_X4FbqnzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mtqkvQZ2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zFA3FMat_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lSV2W4J9, 0, m, &cSlice_lSV2W4J9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EGsaBGUB_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_lSV2W4J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_juyGEuQG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_juyGEuQG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_DIuxvv1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_juyGEuQG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_juyGEuQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_on6tXHEE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EGsaBGUB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RyhnfWm2, 0, m, &cSlice_RyhnfWm2_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BvPR4Pv3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_RyhnfWm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fU1pACc5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fU1pACc5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_vtlj73qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fU1pACc5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_fU1pACc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vHjIyZyd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_A9mnWIvQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p2mEKFdS, 0, m, &cSlice_p2mEKFdS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LWVd0K0X_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_p2mEKFdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SCy1WLKz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SCy1WLKz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_10WicyA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SCy1WLKz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SCy1WLKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mhmmJfI7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LWVd0K0X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Cjgmy9jM, 0, m, &cSlice_Cjgmy9jM_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Cjgmy9jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3fRRJnxJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3fRRJnxJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_gdHNRnqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3fRRJnxJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_3fRRJnxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BnadlV5c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1RbLOT1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ysbQBpB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kBVC6PlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XevuE1MU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_HAvPgjkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2OTBiuDF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_29hBITs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ltqLCvNo, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_asfVLE6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e2wYagdH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_o5AMYh1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cJW6ObHv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_cJW6ObHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_11PoUf3l, HV_BINOP_DIVIDE, 1, m, &cBinop_11PoUf3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PUibK3j4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_9t2rkX7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_OePwNDG4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_2Su01hGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_9t2rkX7Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OePwNDG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_11PoUf3l, HV_BINOP_DIVIDE, 0, m, &cBinop_11PoUf3l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PUibK3j4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2Su01hGd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_11PoUf3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bo8o7rbf, HV_BINOP_MULTIPLY, 1, m, &cBinop_Bo8o7rbf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Bo8o7rbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EOUiTHmi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4sbWpa0X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_4aynfg5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jxO6hVmJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_BbETGt6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wiXLLwUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_LAdy2WaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_FkUGMkFi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FkUGMkFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bo8o7rbf, HV_BINOP_MULTIPLY, 0, m, &cBinop_Bo8o7rbf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pQTvgctB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8lfKc6mE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8lfKc6mE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uh8pMy2A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_73S3cSuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jb6ZASUw, 1, m, &cVar_Jb6ZASUw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Jb6ZASUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DjyQ9ue1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Jww3MfGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3SUUGtn, HV_BINOP_MULTIPLY, 1, m, &cBinop_k3SUUGtn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Ba5b1huY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Jww3MfGZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dzV6hJmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OutTHKO2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OutTHKO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Atu4hkQT, HV_BINOP_MULTIPLY, 1, m, &cBinop_Atu4hkQT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HwJRFmAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzOY5DWK, HV_BINOP_MULTIPLY, 1, m, &cBinop_MzOY5DWK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cupgtWLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HwJRFmAL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ndOF5PV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lH5f7eCJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_lH5f7eCJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_MBGytfn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0I9B96ri_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0I9B96ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cc7a9lF1, HV_BINOP_MULTIPLY, 1, m, &cBinop_Cc7a9lF1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_qCMbD48w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tlM5dGES_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_LAdy2WaX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wP7IyfTs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_4tGQFM36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_pQTvgctB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EOUiTHmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_4aynfg5n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4sbWpa0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_BbETGt6g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_jxO6hVmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lSKngjFK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wiXLLwUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A3QnRbdC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_FbJ6iBA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Vmu84IVi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_uh8pMy2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_IrvHCqTG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IrvHCqTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lQ0LzQKg, HV_BINOP_MULTIPLY, 1, m, &cBinop_lQ0LzQKg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lQ0LzQKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gNQulQmD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gNQulQmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FbJ6iBA6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_DjyQ9ue1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Nl3maZgR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Nl3maZgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vIuq69f4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OAblnTle_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l63uhdLU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X4oNKsVT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5d2O2xpy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BlG7I7d0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k3SUUGtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1RbLOT1c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Atu4hkQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kBVC6PlM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MzOY5DWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HAvPgjkq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lH5f7eCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_29hBITs0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Cc7a9lF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_asfVLE6a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_S5Ug30B3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4tGQFM36, 1, m, &cVar_4tGQFM36_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PnWoaOUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qCMbD48w, 0, m, &cVar_qCMbD48w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_X4oNKsVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MzOY5DWK, HV_BINOP_MULTIPLY, 0, m, &cBinop_MzOY5DWK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5d2O2xpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Atu4hkQT, HV_BINOP_MULTIPLY, 0, m, &cBinop_Atu4hkQT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_l63uhdLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lH5f7eCJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_lH5f7eCJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OAblnTle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cc7a9lF1, HV_BINOP_MULTIPLY, 0, m, &cBinop_Cc7a9lF1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_BlG7I7d0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k3SUUGtn, HV_BINOP_MULTIPLY, 0, m, &cBinop_k3SUUGtn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vIuq69f4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_tlM5dGES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4tGQFM36, 0, m, &cVar_4tGQFM36_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wP7IyfTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jb6ZASUw, 0, m, &cVar_Jb6ZASUw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vz7MJKRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sKxEBaVF, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_69NmN35S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZCc9FQ3S, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_x9q4wAaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_D5uydbcL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WUUKMVn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VNJ3LWZc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_7lnwUPJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5U87lmkz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_5U87lmkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oKwGi8TC, HV_BINOP_DIVIDE, 1, m, &cBinop_oKwGi8TC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_asvQqvHs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_X94qFeOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_FE8yp9fB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rZNcjk7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_X94qFeOp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FE8yp9fB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oKwGi8TC, HV_BINOP_DIVIDE, 0, m, &cBinop_oKwGi8TC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_asvQqvHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rZNcjk7L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_oKwGi8TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zQ6Ej5kL, HV_BINOP_MULTIPLY, 1, m, &cBinop_zQ6Ej5kL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zQ6Ej5kL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NMnrykmp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Is5wZAh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_rKbyb7sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EuE2Q8rJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_3tbBOe9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SQRFrAp6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ES6nuIeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ZWoKlpAB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZWoKlpAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zQ6Ej5kL, HV_BINOP_MULTIPLY, 0, m, &cBinop_zQ6Ej5kL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tGUEJ4up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Bx0u3M74_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Bx0u3M74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dJQesyaE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MB7UuIw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TDXYRynB, HV_BINOP_MULTIPLY, 1, m, &cBinop_TDXYRynB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OU82MSUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BbtPfi49, 1, m, &cVar_BbtPfi49_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IEFT2zXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i55mtCR3, HV_BINOP_MULTIPLY, 1, m, &cBinop_i55mtCR3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ubBEtW5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_V924dbIP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V924dbIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tkEkgFok, HV_BINOP_MULTIPLY, 1, m, &cBinop_tkEkgFok_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_BbtPfi49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2HCUT0kp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_C1xvQ1Tv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cV6qUEeQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ES6nuIeG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WE1utFgT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_CzT3dvE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_tGUEJ4up_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NMnrykmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rKbyb7sf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_9Is5wZAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3tbBOe9e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_EuE2Q8rJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QWraSSkP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_SQRFrAp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yckM5lrB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_xcODEvup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3PqO7Fv5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_dJQesyaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OCfHLlQx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OCfHLlQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Aa8eae8o, HV_BINOP_MULTIPLY, 1, m, &cBinop_Aa8eae8o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Aa8eae8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_YWTeRcCY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YWTeRcCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xcODEvup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_2HCUT0kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iLJxWN4Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_iLJxWN4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GzbLrCJi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ymQKyYf4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ry2qP8RN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HSsNbWlO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IhtTf5L6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vz7MJKRl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TDXYRynB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_69NmN35S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_i55mtCR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x9q4wAaJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_tkEkgFok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WUUKMVn6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_ZK78cM49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C1xvQ1Tv, 0, m, &cVar_C1xvQ1Tv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MZAeiVv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CzT3dvE7, 1, m, &cVar_CzT3dvE7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WE1utFgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BbtPfi49, 0, m, &cVar_BbtPfi49_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cV6qUEeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CzT3dvE7, 0, m, &cVar_CzT3dvE7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ry2qP8RN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TDXYRynB, HV_BINOP_MULTIPLY, 0, m, &cBinop_TDXYRynB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ymQKyYf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i55mtCR3, HV_BINOP_MULTIPLY, 0, m, &cBinop_i55mtCR3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_GzbLrCJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tkEkgFok, HV_BINOP_MULTIPLY, 0, m, &cBinop_tkEkgFok_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HSsNbWlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IhtTf5L6, HV_BINOP_MULTIPLY, 0, m, &cBinop_IhtTf5L6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_L3WnlKZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pDWysr7I, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_g6X5PTCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3tq71ZAO, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_9BO4aDXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_96W9wN3x, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_1SplIfU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VOZg2Mln, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GmIctqci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uE5CAFB6, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_83SBypBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MJbsvDPZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_MJbsvDPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wf8114uX, HV_BINOP_DIVIDE, 1, m, &cBinop_wf8114uX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_75t5sQyX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_fAQeOPG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_sYRSyjwh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9wVhJvwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fAQeOPG3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sYRSyjwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wf8114uX, HV_BINOP_DIVIDE, 0, m, &cBinop_wf8114uX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_75t5sQyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9wVhJvwj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_wf8114uX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qA0t29c8, HV_BINOP_MULTIPLY, 1, m, &cBinop_qA0t29c8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qA0t29c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WSHWYWjB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o4uaieVs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Cp7Q9rr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G9vtzsKq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_rfYR1Eae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CTgKAKZ2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_3ctCudRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_S4On8K9k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_S4On8K9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qA0t29c8, HV_BINOP_MULTIPLY, 0, m, &cBinop_qA0t29c8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UxIkInmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Qh8SoBfQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qh8SoBfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fS8t1MlZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_z142sYag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cnrkoUbv, HV_BINOP_MULTIPLY, 1, m, &cBinop_cnrkoUbv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UUOtLBgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZFWodKz7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ZFWodKz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_z142sYag_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kJHUaocp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_t2sZqTAB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_t2sZqTAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GMAMCpUn, HV_BINOP_MULTIPLY, 1, m, &cBinop_GMAMCpUn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XnCXBFtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfsKdyNm, HV_BINOP_MULTIPLY, 1, m, &cBinop_MfsKdyNm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_JVVw5EaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rIbWuuIc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rIbWuuIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XnCXBFtW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EsKJCzBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5bvkCIg9, 1, m, &cVar_5bvkCIg9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jv6XRdBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gU0bVTsG, HV_BINOP_MULTIPLY, 1, m, &cBinop_gU0bVTsG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_F4ZbYCT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eIzAM4aK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eIzAM4aK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_McxmcVcy, HV_BINOP_MULTIPLY, 1, m, &cBinop_McxmcVcy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_5bvkCIg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4kpeyKRr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_d8KPRMoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gR9fJZxx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3ctCudRo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kLOFWAeF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_8y3E4xqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UxIkInmA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_o4uaieVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_rfYR1Eae_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_WSHWYWjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Cp7Q9rr2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_G9vtzsKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0MyopZAM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_CTgKAKZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7oUt5WTp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_oWytf6Dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EFitRDIS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fS8t1MlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vwiLQ3s6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vwiLQ3s6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D85PkUbt, HV_BINOP_MULTIPLY, 1, m, &cBinop_D85PkUbt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D85PkUbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gYFVqGmo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gYFVqGmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oWytf6Dx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_4kpeyKRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EKPPLnNC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EKPPLnNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zbamOpMh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ufoB1QrQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Rd8qcIKq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VZ2N3l19_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wP4yI7IC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JU6zIPXQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cnrkoUbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L3WnlKZP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_GMAMCpUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g6X5PTCn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_MfsKdyNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9BO4aDXN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gU0bVTsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1SplIfU6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_McxmcVcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GmIctqci_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_AgKNmAUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d8KPRMoa, 0, m, &cVar_d8KPRMoa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kCVy1mWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8y3E4xqD, 1, m, &cVar_8y3E4xqD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VZ2N3l19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfsKdyNm, HV_BINOP_MULTIPLY, 0, m, &cBinop_MfsKdyNm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_JU6zIPXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cnrkoUbv, HV_BINOP_MULTIPLY, 0, m, &cBinop_cnrkoUbv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_wP4yI7IC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GMAMCpUn, HV_BINOP_MULTIPLY, 0, m, &cBinop_GMAMCpUn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ufoB1QrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_McxmcVcy, HV_BINOP_MULTIPLY, 0, m, &cBinop_McxmcVcy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zbamOpMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_Rd8qcIKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gU0bVTsG, HV_BINOP_MULTIPLY, 0, m, &cBinop_gU0bVTsG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gR9fJZxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8y3E4xqD, 0, m, &cVar_8y3E4xqD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_kLOFWAeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5bvkCIg9, 0, m, &cVar_5bvkCIg9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QdjkNIKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X4FbqnzU, 1, m, &cIf_X4FbqnzU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tZD9eXxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mtqkvQZ2, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TGWP7lb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tZD9eXxL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QZ7V2qDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X4FbqnzU, 0, m, &cIf_X4FbqnzU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sTJnxQD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jbhf16JM, HV_BINOP_DIVIDE, 0, m, &cBinop_jbhf16JM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_g1B3dmE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fd8rmKN0, HV_BINOP_DIVIDE, 1, m, &cBinop_Fd8rmKN0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jbhf16JM, HV_BINOP_DIVIDE, 1, m, &cBinop_jbhf16JM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_k760CBZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u3y2Ns2t, HV_BINOP_DIVIDE, 0, m, &cBinop_u3y2Ns2t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_u26HIPip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u3y2Ns2t, HV_BINOP_DIVIDE, 1, m, &cBinop_u3y2Ns2t_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LJGrCP9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g1B3dmE9, 0, m, &cVar_g1B3dmE9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sJkxWj9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sTJnxQD9, 0, m, &cVar_sTJnxQD9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Z6ohelNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fd8rmKN0, HV_BINOP_DIVIDE, 0, m, &cBinop_Fd8rmKN0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fd8rmKN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_k760CBZ9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jbhf16JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_u26HIPip_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u3y2Ns2t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_EQa4C1xi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_omKUWe13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_uyOUsW9r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zJvepBP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_6W5yUNoq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EQa4C1xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zJvepBP9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6W5yUNoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_omKUWe13_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uyOUsW9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YknGSoqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zntS9TdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WsgKNdMb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_5VTM89si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Je8jOxDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_7mkBRV16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5hKVAj2d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_LnubFnCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_53RC8Dzk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_J7tIJIiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IANHZx5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_40PWNdBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yiYNkCSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_DtvgWpAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zh3hnFYB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_vtcmB4Fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rdfni0yh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_SEszYYO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RlXGSvh9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_cr9U8nBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mwD1DKcf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_QuOwtaxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n1HzNojs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_XhZPSVYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uMAVVjeM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KVqd0qpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7TBcRkRD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7TBcRkRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_aSSq0zQ2, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nT7VKDri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zEYJfjpE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_zEYJfjpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_v2s7anWw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Q2GblK2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fymDX4eC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_qZ4XlRJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_erKBxLLa_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CSgJi2Pz, m);
}

void Heavy_WSTD_FL3NGR::cBinop_v2s7anWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M7Jszxhc, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fymDX4eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qZ4XlRJc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_erKBxLLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_i2Lgxisq, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zfJspDx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_T6BeMQhm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_T6BeMQhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kbU1vsLR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Dh7T575h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nV5PRSk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_ehcKeWP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_u07sxMZj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qxpCoe9i, m);
}

void Heavy_WSTD_FL3NGR::cBinop_kbU1vsLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gHvuEo4Z, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nV5PRSk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ehcKeWP7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_u07sxMZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DX14AEFm, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0VeHe32h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qWkKrYG8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qWkKrYG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_klVNPUyW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_BGtuDRgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WOfLWLRj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_Nd9I9m9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mBfFUxG3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_klVNPUyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_G5tHkW2h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_G5tHkW2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r1zX46Qy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hYMIdVNj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_r1zX46Qy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mb4aVQBr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hYMIdVNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mBzrIjvb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mb4aVQBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xkg8LKc2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mBzrIjvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x8K8UnCw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_x8K8UnCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ljBYY5Lz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xkg8LKc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_BGtuDRgw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ljBYY5Lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Nd9I9m9R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d3T9lJ0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_19i0RGfx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_19i0RGfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BybWqazi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VXhwTWHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_x4fYSF76_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_x4fYSF76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4Q71bKTj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_WDdUG2Fs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WDdUG2Fs, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h2IvWvHb, 0, m, &cDelay_h2IvWvHb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WDdUG2Fs, 0, m, &cDelay_WDdUG2Fs_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_d6k9Y9DJ, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_h2IvWvHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h2IvWvHb, m);
  cMsg_y3UsZYNV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_EcBRyzd6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_hbcGmqKd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_qXf2iTnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GWRgZvED_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_eCZnRzuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZK4HXvKK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WDdUG2Fs, 2, m, &cDelay_WDdUG2Fs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gStxcbTV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GWRgZvED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_eCZnRzuX, 0, m, &hTable_eCZnRzuX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4Q71bKTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_qXf2iTnN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_y3UsZYNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_eCZnRzuX, 0, m, &hTable_eCZnRzuX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_gStxcbTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WDdUG2Fs, 0, m, &cDelay_WDdUG2Fs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ZK4HXvKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_h2IvWvHb, 2, m, &cDelay_h2IvWvHb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_hbcGmqKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_d6k9Y9DJ, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_ArOv83Ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pY0ylp8Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_pY0ylp8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_o5AcSmvU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_ifIY0KGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ifIY0KGC, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hN37y9AI, 0, m, &cDelay_hN37y9AI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ifIY0KGC, 0, m, &cDelay_ifIY0KGC_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8r0opVp0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_hN37y9AI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hN37y9AI, m);
  cMsg_IRoBK6Lx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_eh2r1ahp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_xCvkPQdq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_fp3VJF31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WrKDKmwe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_YDMblDWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LhiBXCMI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ifIY0KGC, 2, m, &cDelay_ifIY0KGC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nk3CT1lp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WrKDKmwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YDMblDWI, 0, m, &hTable_YDMblDWI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_o5AcSmvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_fp3VJF31_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_IRoBK6Lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YDMblDWI, 0, m, &hTable_YDMblDWI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nk3CT1lp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ifIY0KGC, 0, m, &cDelay_ifIY0KGC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LhiBXCMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hN37y9AI, 2, m, &cDelay_hN37y9AI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xCvkPQdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8r0opVp0, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_MLWLenhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w76tORhF, HV_BINOP_MULTIPLY, 0, m, &cBinop_w76tORhF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XWIEGeWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qhXiTaMX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_qhXiTaMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rQjAwjaW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_w76tORhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8VWXxBUu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TCskVkdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w76tORhF, HV_BINOP_MULTIPLY, 1, m, &cBinop_w76tORhF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rQjAwjaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TCskVkdq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8VWXxBUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DuFtBZcj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DuFtBZcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_K4GRwYsu_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BAOSekNA, m);
}

void Heavy_WSTD_FL3NGR::cBinop_K4GRwYsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_atPASC2d, m);
}

void Heavy_WSTD_FL3NGR::cVar_2tqhOhIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GMrHyqX, HV_BINOP_MULTIPLY, 0, m, &cBinop_1GMrHyqX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ATPGgWgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bMe8nQgz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_bMe8nQgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7C5GHfkI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1GMrHyqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_W88lvspJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4SKzy5AU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GMrHyqX, HV_BINOP_MULTIPLY, 1, m, &cBinop_1GMrHyqX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7C5GHfkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_4SKzy5AU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W88lvspJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LKBbvpfi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_LKBbvpfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1HATLoQI_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tUqKzdsW, m);
}

void Heavy_WSTD_FL3NGR::cBinop_1HATLoQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Rzj7KnDO, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BybWqazi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mGgjHH19, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_xUA8Xij0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_jbaLMDms_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CTeqmcww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Gtl3wtUX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_W3t8maVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_xUA8Xij0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_itRlapNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lkjnGkkY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lkjnGkkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2RPWtRw1, HV_BINOP_MULTIPLY, 1, m, &cBinop_2RPWtRw1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gtl3wtUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_itRlapNf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2RPWtRw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T2Zr2Hxt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_jbaLMDms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2RPWtRw1, HV_BINOP_MULTIPLY, 0, m, &cBinop_2RPWtRw1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_T2Zr2Hxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ddTGuu18, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_GtYlxZvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_5xzlZZ0O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5xzlZZ0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CTeqmcww_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W3t8maVk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_19HlFGFU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cY2zgRwV, 0, m, &cSlice_cY2zgRwV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DgnWSO5q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_cY2zgRwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_amcwQPZF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_amcwQPZF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_xeTaMyqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_amcwQPZF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_amcwQPZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LQW7bOHb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_DgnWSO5q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bLACW62F, 0, m, &cSlice_bLACW62F_sendMessage);
      break;
    }
    default: {
      cSwitchcase_M1UE0lPU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_bLACW62F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Jm4vIn6d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Jm4vIn6d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_DhuOtQbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Jm4vIn6d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Jm4vIn6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9dJt3I2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_M1UE0lPU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ZX6Qz4J9, 0, m, &cSlice_ZX6Qz4J9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TXTIW0u6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ZX6Qz4J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Tx7Hcg2r_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Tx7Hcg2r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_l6l3mLfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Tx7Hcg2r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Tx7Hcg2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jimYmw0Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_TXTIW0u6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qJ8xujid, 0, m, &cSlice_qJ8xujid_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_qJ8xujid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MML1AL8Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MML1AL8Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_nJaElYrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MML1AL8Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MML1AL8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0y3TJLH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WOfLWLRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vpP7CNDs, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mBfFUxG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qNYd6fUl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_6TZ2MMrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yU8asBgy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yU8asBgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_0kAFjnUv, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SnXhI29v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TLF29Ir1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_TLF29Ir1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2qoCgBuu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_PRWW266o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nARkrZaA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_bmeaLWGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ccb4pQwF_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_NP1aZwzc, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2qoCgBuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FDLwfvk8, m);
}

void Heavy_WSTD_FL3NGR::cMsg_nARkrZaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bmeaLWGk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ccb4pQwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5zNYxgBd, m);
}

void Heavy_WSTD_FL3NGR::cMsg_WB6tpaNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_T8do3AoO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_T8do3AoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BCid82XC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_yLhL5Pix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F7YFsWvt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_MvWD5OJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VSbhD0qH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_lDTNSX0u, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BCid82XC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OiYS5oB3, m);
}

void Heavy_WSTD_FL3NGR::cMsg_F7YFsWvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MvWD5OJG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VSbhD0qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vGJhvU7k, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6sVNBpLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SdKL6XCR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SdKL6XCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_yEbhL1ym_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_vW4RpFIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fDALhN5v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_pKEmGn2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MxCbIp4K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_yEbhL1ym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_scD3Ppqv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_scD3Ppqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qxE9HI9K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sEEWhGGD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qxE9HI9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YBEGE5XS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sEEWhGGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I0ENwSIj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_YBEGE5XS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Wl7KcTT4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_I0ENwSIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_aQCRpjtf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aQCRpjtf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yqtsDnJC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wl7KcTT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_vW4RpFIS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yqtsDnJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_pKEmGn2k_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4fhSXTO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_sO2LEjkG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sO2LEjkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rLhg7imv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_sHb2OwmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YpfBBg3Y_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_YpfBBg3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_YCeZnJS7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_UY2krhXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UY2krhXW, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XCnwkRLN, 0, m, &cDelay_XCnwkRLN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UY2krhXW, 0, m, &cDelay_UY2krhXW_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IkxtV3Y1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_XCnwkRLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XCnwkRLN, m);
  cMsg_sdOWMGvy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_QqJCpj7B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ahKOscN8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_AShHLpIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mmlQOuxg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_HqUfuLZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0B6a6Fke_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UY2krhXW, 2, m, &cDelay_UY2krhXW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T8h6hcVm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mmlQOuxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_HqUfuLZA, 0, m, &hTable_HqUfuLZA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YCeZnJS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_AShHLpIG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sdOWMGvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_HqUfuLZA, 0, m, &hTable_HqUfuLZA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T8h6hcVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UY2krhXW, 0, m, &cDelay_UY2krhXW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0B6a6Fke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_XCnwkRLN, 2, m, &cDelay_XCnwkRLN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ahKOscN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_IkxtV3Y1, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6JmyLdO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CghEuhRb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_CghEuhRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_cd3EVlU4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_JrskxZfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JrskxZfa, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_XsrFi32F, 0, m, &cDelay_XsrFi32F_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JrskxZfa, 0, m, &cDelay_JrskxZfa_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVTt7Ugm, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_XsrFi32F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XsrFi32F, m);
  cMsg_KvDUM7w1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xDhIo5y2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_eSqVudxA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_wbNFZkW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tjWIrApL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_gvXJTePX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9xUsww5W_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JrskxZfa, 2, m, &cDelay_JrskxZfa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nWN1truI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_tjWIrApL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_gvXJTePX, 0, m, &hTable_gvXJTePX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cd3EVlU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_wbNFZkW7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KvDUM7w1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_gvXJTePX, 0, m, &hTable_gvXJTePX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nWN1truI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JrskxZfa, 0, m, &cDelay_JrskxZfa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9xUsww5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_XsrFi32F, 2, m, &cDelay_XsrFi32F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eSqVudxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GVTt7Ugm, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_vAMGwd8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mA9kvWCo, HV_BINOP_MULTIPLY, 0, m, &cBinop_mA9kvWCo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PJIenr1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aNnPvvgj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_aNnPvvgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_btJc75lP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mA9kvWCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_D2fCyNm3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Oj3k2dwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mA9kvWCo, HV_BINOP_MULTIPLY, 1, m, &cBinop_mA9kvWCo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_btJc75lP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Oj3k2dwZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_D2fCyNm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Qnx5V2BG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qnx5V2BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BEJkWpbd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8Hjkxk4m, m);
}

void Heavy_WSTD_FL3NGR::cBinop_BEJkWpbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HiPMxiXW, m);
}

void Heavy_WSTD_FL3NGR::cVar_R91Kx3bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Y4yh7QL, HV_BINOP_MULTIPLY, 0, m, &cBinop_4Y4yh7QL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mtd3XZcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Zk6yhtOA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Zk6yhtOA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_co0YZEzW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4Y4yh7QL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vtQiuPOi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_APal22Yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Y4yh7QL, HV_BINOP_MULTIPLY, 1, m, &cBinop_4Y4yh7QL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_co0YZEzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_APal22Yr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vtQiuPOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_F94h2Ow5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F94h2Ow5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_6K4TX9TA_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_PpBkEqbU, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6K4TX9TA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_8rqWJ9qG, m);
}

void Heavy_WSTD_FL3NGR::cMsg_rLhg7imv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iy8sS39E, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_HmsbqSZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_rI6BaKA0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OQkFI8Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2KdDfQWq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_193HrVYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_HmsbqSZi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_eMTdTvjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OAbNkY09_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OAbNkY09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VIFNhEgU, HV_BINOP_MULTIPLY, 1, m, &cBinop_VIFNhEgU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2KdDfQWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_eMTdTvjT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VIFNhEgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WihTEvrQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rI6BaKA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VIFNhEgU, HV_BINOP_MULTIPLY, 0, m, &cBinop_VIFNhEgU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_WihTEvrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tfBHz0zv, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ce0cs4Xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_FbqlaQu9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FbqlaQu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OQkFI8Im_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_193HrVYA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_FsQT4Oum_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z9BpsKte, 0, m, &cSlice_z9BpsKte_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NdQQ4bx4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_z9BpsKte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vOWwAO4c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vOWwAO4c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_rtbxg7St_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vOWwAO4c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vOWwAO4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rvvAgXyT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_NdQQ4bx4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DQ8hCh7v, 0, m, &cSlice_DQ8hCh7v_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UEXlVf7q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_DQ8hCh7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7IbiCxv7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7IbiCxv7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_mEAFbbF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7IbiCxv7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_7IbiCxv7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5v8DEiqM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_UEXlVf7q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OdstaG4I, 0, m, &cSlice_OdstaG4I_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HNLCfK68_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_OdstaG4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IvLtTBGh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IvLtTBGh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_rgLTGcKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IvLtTBGh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_IvLtTBGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IGS9p1MP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_HNLCfK68_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bAezqD6d, 0, m, &cSlice_bAezqD6d_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_bAezqD6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Ir66tF0Q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Ir66tF0Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ilnIuaKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ir66tF0Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Ir66tF0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ein91BTh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fDALhN5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zW8FhS2g, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MxCbIp4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v6vYAkJS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_sG9jgk5v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XsNGFd35_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XsNGFd35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_1ymnvXLM, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_qFIjJCui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_26hR75Ws_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_26hR75Ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HrNlOZN9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_SgfRqW1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BnwO18x5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_EhnhSSiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QiAuiMWl_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hpXofNmu, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HrNlOZN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_M0iWlVkV, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BnwO18x5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EhnhSSiS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QiAuiMWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4mSDDmUB, m);
}

void Heavy_WSTD_FL3NGR::cMsg_NvoIBG1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EQemI9b2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_EQemI9b2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QV1xTsfa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_zHUiAXDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SUo2wGC1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_Emf1N3KO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ImCL5ixT_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WFNc9U6L, m);
}

void Heavy_WSTD_FL3NGR::cBinop_QV1xTsfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Uafbze2d, m);
}

void Heavy_WSTD_FL3NGR::cMsg_SUo2wGC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Emf1N3KO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ImCL5ixT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JLiweLU6, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Ak57q8bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_F5jo1rm7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F5jo1rm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vrvGJA52_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_EWytWx2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0J3L01Ez_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_S78X9x75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uSo7Gzhk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vrvGJA52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qtB6ih4w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qtB6ih4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aAovkjyT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5u3DWNIm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aAovkjyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2pF1KZPS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5u3DWNIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H1P9WXKd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2pF1KZPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CQa68WTC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_H1P9WXKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EYVp8vey_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EYVp8vey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lvvbLTNH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CQa68WTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_EWytWx2d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lvvbLTNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_S78X9x75_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pUpskdrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QxxpIPvT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QxxpIPvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fypIR7xD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_K7jNxDYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9zUvRqNJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_9zUvRqNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jxXCTgAu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_Npufu9Cw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Npufu9Cw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PwFSRuzn, 0, m, &cDelay_PwFSRuzn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Npufu9Cw, 0, m, &cDelay_Npufu9Cw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9h7bDaGc, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_PwFSRuzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PwFSRuzn, m);
  cMsg_NBGRQDRx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_yW5ihzsT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qSDAOrz7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_pvKTP6of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8B8q9L53_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_H13OjF3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rV3AnTqV_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Npufu9Cw, 2, m, &cDelay_Npufu9Cw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZZVhqKoM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_8B8q9L53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_H13OjF3D, 0, m, &hTable_H13OjF3D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jxXCTgAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_pvKTP6of_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_NBGRQDRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_H13OjF3D, 0, m, &hTable_H13OjF3D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZZVhqKoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Npufu9Cw, 0, m, &cDelay_Npufu9Cw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_rV3AnTqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_PwFSRuzn, 2, m, &cDelay_PwFSRuzn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qSDAOrz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_9h7bDaGc, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_kuwWBODf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7kC5wfZ1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_7kC5wfZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_sFrnbgyG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_bn2yNHWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bn2yNHWq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gxlx0yu0, 0, m, &cDelay_gxlx0yu0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bn2yNHWq, 0, m, &cDelay_bn2yNHWq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TKjU5b8i, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_gxlx0yu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gxlx0yu0, m);
  cMsg_Io9nQIco_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_JSETTBjJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_riosM8S5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_GdBTaMhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O4zgVNxj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_t2j1JVpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_81Lw8agS_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bn2yNHWq, 2, m, &cDelay_bn2yNHWq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YGCFy4Ei_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_O4zgVNxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_t2j1JVpz, 0, m, &hTable_t2j1JVpz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sFrnbgyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_GdBTaMhD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Io9nQIco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_t2j1JVpz, 0, m, &hTable_t2j1JVpz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YGCFy4Ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bn2yNHWq, 0, m, &cDelay_bn2yNHWq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_81Lw8agS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gxlx0yu0, 2, m, &cDelay_gxlx0yu0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_riosM8S5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TKjU5b8i, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_pYFJInuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lZNR8Tju, HV_BINOP_MULTIPLY, 0, m, &cBinop_lZNR8Tju_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_i0GRxl91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xaU8Fb83_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_xaU8Fb83_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3g5r7jHO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lZNR8Tju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pMRUutCp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FlC9x29M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lZNR8Tju, HV_BINOP_MULTIPLY, 1, m, &cBinop_lZNR8Tju_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3g5r7jHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_FlC9x29M_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pMRUutCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_APX7gG9Z_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_APX7gG9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_n6Uofxm1_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fgUVcT0I, m);
}

void Heavy_WSTD_FL3NGR::cBinop_n6Uofxm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tkFokDFz, m);
}

void Heavy_WSTD_FL3NGR::cVar_6xl6qExe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7vwaLb41, HV_BINOP_MULTIPLY, 0, m, &cBinop_7vwaLb41_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KjhIN6lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KMYci9PN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_KMYci9PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VBKy4hEU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_7vwaLb41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IluH7ldL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zR7yVJsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7vwaLb41, HV_BINOP_MULTIPLY, 1, m, &cBinop_7vwaLb41_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VBKy4hEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zR7yVJsj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IluH7ldL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zZ5tHthq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zZ5tHthq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_amo4bgDd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_noOGaCuB, m);
}

void Heavy_WSTD_FL3NGR::cBinop_amo4bgDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_krCyXWzx, m);
}

void Heavy_WSTD_FL3NGR::cMsg_fypIR7xD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YN0C7G9z, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_9pdAvCKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_dNGYnPAK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1CQimtMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_9pdAvCKg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YrWEkwCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pfw4kxbj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_a0w3hl2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_TncaaChC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TncaaChC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DziASqT1, HV_BINOP_MULTIPLY, 1, m, &cBinop_DziASqT1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pfw4kxbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_a0w3hl2K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DziASqT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dpn0DPaf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_dNGYnPAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DziASqT1, HV_BINOP_MULTIPLY, 0, m, &cBinop_DziASqT1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_dpn0DPaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LxyuLNfM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_8ZvILYZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_qS8K41Je_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qS8K41Je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YrWEkwCJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1CQimtMv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_uBfdgPuU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GmuIdEHZ, 0, m, &cSlice_GmuIdEHZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2SCdDJhs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_GmuIdEHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_F6pEvKv4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_F6pEvKv4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_a4lPbQ1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_F6pEvKv4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_F6pEvKv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bXiej0F4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_2SCdDJhs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jZ3lkEac, 0, m, &cSlice_jZ3lkEac_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lF2PDeHf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_jZ3lkEac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m6ns3d26_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m6ns3d26_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ssmeZUuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m6ns3d26_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_m6ns3d26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Z1n31wp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_lF2PDeHf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8f4FaJdD, 0, m, &cSlice_8f4FaJdD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_B2uyYhFn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_8f4FaJdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ePcnuH9Z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ePcnuH9Z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_Byi1SYeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ePcnuH9Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_ePcnuH9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n1eH0XpC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_B2uyYhFn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zzhGBTSi, 0, m, &cSlice_zzhGBTSi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_zzhGBTSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MyzD71Um_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MyzD71Um_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_wOOjrMGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MyzD71Um_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_MyzD71Um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IgpVDOVj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_0J3L01Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ind7E2o9, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_uSo7Gzhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pwz8mM05, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SbiPFcwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RTFPvQsk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zFA3FMat_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_xsGG3lDQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RTFPvQsk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zFA3FMat_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sSr5vV1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RTFPvQsk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zFA3FMat_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8MVa5Gc0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RTFPvQsk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zFA3FMat_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YknGSoqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RTFPvQsk_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_zFA3FMat_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_CRt8ryBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_8nq4YUSZ, 0, m, &cVar_8nq4YUSZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Pg1cbw5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_6N2P0hLr, 0, m, &cVar_6N2P0hLr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8Y3AvdzL, 0, m, &cVar_8Y3AvdzL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Y4pd2i06, 0, m, &cVar_Y4pd2i06_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_53RC8Dzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_19HlFGFU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_WsgKNdMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_19HlFGFU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Je8jOxDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_19HlFGFU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_5hKVAj2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_19HlFGFU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_TRusugtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LnubFnCl, 0, m, &cVar_LnubFnCl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6PLBOuSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zntS9TdA, 0, m, &cVar_zntS9TdA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WBHeQpnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7mkBRV16, 0, m, &cVar_7mkBRV16_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Rdfni0yh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_FsQT4Oum_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_IANHZx5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_FsQT4Oum_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yiYNkCSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_FsQT4Oum_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zh3hnFYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_FsQT4Oum_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ONf05sJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vtcmB4Fw, 0, m, &cVar_vtcmB4Fw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hvI0ByLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J7tIJIiL, 0, m, &cVar_J7tIJIiL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gzxnb13V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DtvgWpAS, 0, m, &cVar_DtvgWpAS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uMAVVjeM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uBfdgPuU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RlXGSvh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uBfdgPuU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_mwD1DKcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uBfdgPuU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_n1HzNojs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_uBfdgPuU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_NSDY4r5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XhZPSVYT, 0, m, &cVar_XhZPSVYT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kNn06Yz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SEszYYO1, 0, m, &cVar_SEszYYO1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_liWyYZlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QuOwtaxR, 0, m, &cVar_QuOwtaxR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BrY6BfPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6N2P0hLr, 0, m, &cVar_6N2P0hLr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VrE75FPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8Y3AvdzL, 0, m, &cVar_8Y3AvdzL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_8QSRKvRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Y4pd2i06, 0, m, &cVar_Y4pd2i06_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LcvbkXFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_slrckD6n, 0, m, &cVar_slrckD6n_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jj1ATMLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dGxmiy6i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TW6RZFS6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_X7Jbvc33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IMh9jPJA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_30xoAv7O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ph9Etbm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZIOlDtAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yfw2DB0n_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uZO6aXwM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dZNuKybk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_J20NwS4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lWPWXuNs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pay3m2jb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UvVXSFCx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_73LPMVlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8IKnPMD0_sendMessage(_c, 0, m);
  cMsg_65zoR3nA_sendMessage(_c, 0, m);
  cMsg_brafyuXG_sendMessage(_c, 0, m);
  cMsg_o5AMYh1v_sendMessage(_c, 0, m);
  cMsg_7lnwUPJM_sendMessage(_c, 0, m);
  cMsg_83SBypBN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_kaP3wn3j, 0, m, &cVar_kaP3wn3j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_slrckD6n, 0, m, &cVar_slrckD6n_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_o69pDYTm, 0, m, &cVar_o69pDYTm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qCMbD48w, 0, m, &cVar_qCMbD48w_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C1xvQ1Tv, 0, m, &cVar_C1xvQ1Tv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d8KPRMoa, 0, m, &cVar_d8KPRMoa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dD8ShTWG, 0, m, &cVar_dD8ShTWG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wS8RK0BN, 0, m, &cVar_wS8RK0BN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EK9HdYd0, 0, m, &cVar_EK9HdYd0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gbA7N0pL, 0, m, &cVar_gbA7N0pL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cujZ2Fsm, 0, m, &cVar_cujZ2Fsm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mchbRH9f, 0, m, &cVar_mchbRH9f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6z9PnJg0, 0, m, &cVar_6z9PnJg0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AGzI4t8e, 0, m, &cVar_AGzI4t8e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6yaBKbAE, 0, m, &cVar_6yaBKbAE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xwcDa7Pz, 0, m, &cVar_xwcDa7Pz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cPykEOJk, 0, m, &cVar_cPykEOJk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A9XBp6JI, 0, m, &cVar_A9XBp6JI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DIuxvv1Z, 0, m, &cVar_DIuxvv1Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vtlj73qs, 0, m, &cVar_vtlj73qs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_10WicyA6, 0, m, &cVar_10WicyA6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gdHNRnqy, 0, m, &cVar_gdHNRnqy_sendMessage);
  cMsg_XWIEGeWb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MLWLenhs, 0, m, &cVar_MLWLenhs_sendMessage);
  cMsg_ATPGgWgm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2tqhOhIK, 0, m, &cVar_2tqhOhIK_sendMessage);
  cMsg_PJIenr1P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vAMGwd8g, 0, m, &cVar_vAMGwd8g_sendMessage);
  cMsg_mtd3XZcJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_R91Kx3bq, 0, m, &cVar_R91Kx3bq_sendMessage);
  cMsg_i0GRxl91_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pYFJInuq, 0, m, &cVar_pYFJInuq_sendMessage);
  cMsg_KjhIN6lr_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_6xl6qExe, 0, m, &cVar_6xl6qExe_sendMessage);
  cMsg_VXhwTWHd_sendMessage(_c, 0, m);
  cMsg_ArOv83Ri_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xeTaMyqO, 0, m, &cVar_xeTaMyqO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DhuOtQbf, 0, m, &cVar_DhuOtQbf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l6l3mLfV, 0, m, &cVar_l6l3mLfV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nJaElYrY, 0, m, &cVar_nJaElYrY_sendMessage);
  cMsg_sHb2OwmF_sendMessage(_c, 0, m);
  cMsg_6JmyLdO4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rtbxg7St, 0, m, &cVar_rtbxg7St_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mEAFbbF8, 0, m, &cVar_mEAFbbF8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rgLTGcKO, 0, m, &cVar_rgLTGcKO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ilnIuaKA, 0, m, &cVar_ilnIuaKA_sendMessage);
  cMsg_K7jNxDYO_sendMessage(_c, 0, m);
  cMsg_kuwWBODf_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_a4lPbQ1X, 0, m, &cVar_a4lPbQ1X_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ssmeZUuv, 0, m, &cVar_ssmeZUuv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Byi1SYeB, 0, m, &cVar_Byi1SYeB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wOOjrMGU, 0, m, &cVar_wOOjrMGU_sendMessage);
  cMsg_Pg1cbw5o_sendMessage(_c, 0, m);
  cMsg_CRt8ryBL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Q2GblK2N, 0, m, &cVar_Q2GblK2N_sendMessage);
  cMsg_nT7VKDri_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Dh7T575h, 0, m, &cVar_Dh7T575h_sendMessage);
  cMsg_zfJspDx1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PRWW266o, 0, m, &cVar_PRWW266o_sendMessage);
  cMsg_SnXhI29v_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yLhL5Pix, 0, m, &cVar_yLhL5Pix_sendMessage);
  cMsg_WB6tpaNh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SgfRqW1z, 0, m, &cVar_SgfRqW1z_sendMessage);
  cMsg_qFIjJCui_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zHUiAXDX, 0, m, &cVar_zHUiAXDX_sendMessage);
  cMsg_NvoIBG1r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_myC3Ju7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yN0nYmFD, HV_BINOP_MULTIPLY, 0, m, &cBinop_yN0nYmFD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_FFLORQk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VpfCsnpw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_W291dg76_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oi92zc6q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_7hFMJcKJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Rg6kBSpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8JeOWeUS_sendMessage);
  cMsg_ATC2vpR1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_YH0mNZUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ut3pQmmZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ut3pQmmZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LIPyz3hJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_eU4C9YuH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_tPPoLJfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qmzp5tMj, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qmzp5tMj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xn4mE1CR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_o4WfNTcU_sendMessage);
  cMsg_iYadGocx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_vnz4Dq3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JN3vhhYS, HV_BINOP_MULTIPLY, 0, m, &cBinop_JN3vhhYS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JyD1A8yD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o5hkMWhL_sendMessage(_c, 0, m);
  cMsg_9URWf9qR_sendMessage(_c, 0, m);
  cMsg_tKo32qYJ_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HVUXew5V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_oqJtjiJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oN5FRzA2_sendMessage);
  cMsg_HSS4oLL7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_gJoVKR0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_C1xvQ1Tv, 0, m, &cVar_C1xvQ1Tv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_BnadlV5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MZAeiVv1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZK78cM49_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_on6tXHEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_obOCQaGi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pn7CpLUp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1E0PqIMb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_mhmmJfI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RsjCeQK1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_62RhIq7s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OJm1OYrr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vHjIyZyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sIbRVwUk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lrjBQU7j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H8QkxApH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lSKngjFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lQ0LzQKg, HV_BINOP_MULTIPLY, 0, m, &cBinop_lQ0LzQKg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_A3QnRbdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Ba5b1huY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dzV6hJmy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cupgtWLV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ndOF5PV1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Vmu84IVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_73S3cSuP_sendMessage);
  cMsg_MBGytfn0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_QWraSSkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Aa8eae8o, HV_BINOP_MULTIPLY, 0, m, &cBinop_Aa8eae8o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yckM5lrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_IEFT2zXG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_3PqO7Fv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IhtTf5L6, HV_BINOP_MULTIPLY, 1, m, &cBinop_IhtTf5L6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_MB7UuIw9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OU82MSUm_sendMessage);
  cMsg_ubBEtW5S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_0MyopZAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D85PkUbt, HV_BINOP_MULTIPLY, 0, m, &cBinop_D85PkUbt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_7oUt5WTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UUOtLBgA_sendMessage(_c, 0, m);
  cMsg_kJHUaocp_sendMessage(_c, 0, m);
  cMsg_JVVw5EaI_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_jv6XRdBy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_EFitRDIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EsKJCzBs_sendMessage);
  cMsg_F4ZbYCT0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_Yvjg5olu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8nq4YUSZ, 0, m, &cVar_8nq4YUSZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_R1xJEcVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TRusugtD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5341HLKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_6PLBOuSZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GGbXnmoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5VTM89si, 0, m, &cVar_5VTM89si_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_om2gSoJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_WBHeQpnW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_RWjcCfs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ONf05sJx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_K5iPhQhx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hvI0ByLs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NmDWRt4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_40PWNdBi, 0, m, &cVar_40PWNdBi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0KqcKFnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_gzxnb13V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VMtdJ5TH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_NSDY4r5b_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_xRpDdHFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_kNn06Yz5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_e6cgufp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cr9U8nBu, 0, m, &cVar_cr9U8nBu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_YVxQmolm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_liWyYZlr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jimYmw0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_KVqd0qpl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_9dJt3I2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_GtYlxZvK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0y3TJLH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0VeHe32h_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LQW7bOHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_d3T9lJ0Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_IGS9p1MP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_6TZ2MMrD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_5v8DEiqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ce0cs4Xg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ein91BTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6sVNBpLU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_rvvAgXyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4fhSXTO9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_n1eH0XpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_sG9jgk5v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Z1n31wp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8ZvILYZJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_IgpVDOVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Ak57q8bu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bXiej0F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pUpskdrR_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_qr1cpeep, VOf(Bf0));
    __hv_line_f(&sLine_YA5tE9ZW, VOf(Bf1));
    __hv_line_f(&sLine_Lxs1CT4r, VOf(Bf2));
    __hv_line_f(&sLine_M7ZkqRRp, VOf(Bf3));
    __hv_line_f(&sLine_oWl9UX9k, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_psbF7GrO, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_ttCiEqun, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_Y3VL6Up5, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_7F0Iy1n2, VOf(Bf1));
    __hv_line_f(&sLine_BkvbSdhi, VOf(Bf0));
    __hv_line_f(&sLine_iXXRw46K, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_J5Y0Kww7, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_sBweHjZw, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_viCUMOaV, VOf(Bf5));
    __hv_line_f(&sLine_jbmcAFq7, VOf(Bf1));
    __hv_line_f(&sLine_SrVD3fza, VOf(Bf2));
    __hv_line_f(&sLine_FL3g09MB, VOf(Bf4));
    __hv_line_f(&sLine_wL9REQJl, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_0sCPtc1l, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_7BBkDdWK, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_8ysbQBpB, VOf(Bf6));
    __hv_line_f(&sLine_XevuE1MU, VOf(Bf2));
    __hv_line_f(&sLine_2OTBiuDF, VOf(Bf1));
    __hv_line_f(&sLine_ltqLCvNo, VOf(Bf5));
    __hv_line_f(&sLine_e2wYagdH, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_32QK89vp, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_1WCoKflS, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_sKxEBaVF, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_ZCc9FQ3S, VOf(Bf2));
    __hv_line_f(&sLine_D5uydbcL, VOf(Bf6));
    __hv_line_f(&sLine_VNJ3LWZc, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_5mCOEDxn, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_mtqkvQZ2, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_pDWysr7I, VOf(Bf8));
    __hv_line_f(&sLine_3tq71ZAO, VOf(Bf2));
    __hv_line_f(&sLine_96W9wN3x, VOf(Bf1));
    __hv_line_f(&sLine_VOZg2Mln, VOf(Bf7));
    __hv_line_f(&sLine_uE5CAFB6, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_9x4yNrfF, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_qk7YxDgO, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_qNYd6fUl, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_aSSq0zQ2, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_mGgjHH19, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_BAOSekNA, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_atPASC2d, VOf(Bf8));
    __hv_rpole_f(&sRPole_Ide6KfcI, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_tUqKzdsW, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Rzj7KnDO, VOf(Bf10));
    __hv_rpole_f(&sRPole_BHsJqVIn, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_BfSM2Maw, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_M7Jszxhc, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_i2Lgxisq, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_CSgJi2Pz, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_17KefS5U, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_GtAavHRB, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_vpP7CNDs, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_ipTgnjpv, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_gHvuEo4Z, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_DX14AEFm, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_qxpCoe9i, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_HTbfjjyE, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_VI3cMZLw, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_ddTGuu18, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_d6k9Y9DJ, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_8r0opVp0, VIf(Bf3));
    __hv_varwrite_f(&sVarf_cgDKvpYz, VIf(Bf11));
    __hv_line_f(&sLine_v6vYAkJS, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_0kAFjnUv, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_iy8sS39E, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_8Hjkxk4m, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_HiPMxiXW, VOf(Bf10));
    __hv_rpole_f(&sRPole_vub0EfSi, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_PpBkEqbU, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_8rqWJ9qG, VOf(Bf5));
    __hv_rpole_f(&sRPole_Qddm0OLI, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_Q582SIub, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_FDLwfvk8, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_5zNYxgBd, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_NP1aZwzc, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_0W6Fy8Zc, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_XA9SFbl0, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_zW8FhS2g, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_dvIRlkbo, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_OiYS5oB3, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_vGJhvU7k, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_lDTNSX0u, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_O2H6Knxf, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_kViT4gSx, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_tfBHz0zv, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_IkxtV3Y1, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_GVTt7Ugm, VIf(Bf0));
    __hv_varwrite_f(&sVarf_kr3C0WgK, VIf(Bf8));
    __hv_line_f(&sLine_Pwz8mM05, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_1ymnvXLM, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_YN0C7G9z, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_fgUVcT0I, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_tkFokDFz, VOf(Bf5));
    __hv_rpole_f(&sRPole_qLgsIPYt, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_noOGaCuB, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_krCyXWzx, VOf(Bf6));
    __hv_rpole_f(&sRPole_NXhUqfIZ, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_xC5gsYBU, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_M0iWlVkV, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_4mSDDmUB, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_hpXofNmu, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_3dfSv3hs, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_T9AswgjU, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_ind7E2o9, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_gv2POoB2, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_Uafbze2d, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_JLiweLU6, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_WFNc9U6L, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_wGF3Xmj3, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_Pksf32qN, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_LxyuLNfM, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_9h7bDaGc, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_TKjU5b8i, VIf(Bf4));
    __hv_varwrite_f(&sVarf_vLTB31gB, VIf(Bf10));
    __hv_varwrite_f(&sVarf_y9oaYRgo, VIf(Bf2));
    __hv_varwrite_f(&sVarf_TYkHUUcn, VIf(Bf9));
    __hv_varwrite_f(&sVarf_Zgp8ZjrR, VIf(Bf11));
    __hv_varread_f(&sVarf_cgDKvpYz, VOf(Bf11));
    __hv_varread_f(&sVarf_kr3C0WgK, VOf(Bf9));
    __hv_varread_f(&sVarf_vLTB31gB, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_y9oaYRgo, VOf(Bf2));
    __hv_varread_f(&sVarf_TYkHUUcn, VOf(Bf11));
    __hv_varread_f(&sVarf_Zgp8ZjrR, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
